==> payroll_ver_3.2.2.zip: payroll3/src/jp/mosp/payroll/payment/vo/StartCalcVo.java <==
package jp.mosp.payroll.payment.vo;

import javax.servlet.http.HttpServletRequest;

import jp.mosp.payroll.base.PayrollVo;

/**
 * ^vZJnʂɊւB
 */
public class StartCalcVo extends PayrollVo {
	
	private static final long serialVersionUID = 6398055375236133331L;
	
	// tB[h
	private int pltYear;
	private int pltMonth;
	
	// v_E
	private String[][] pitYear ;
	private String[][] pitMonth;
	
	// ʃ[h
	private int mode;
	
	/**
	 * p[^(^vZJnN)B
	 */
	public static final String PRM_PLT_YEAR = "pltYear";
	
	/**
	 * p[^(^vZJn)B
	 */
	public static final String PRM_PLT_MONTH = "pltMonth";
	
	/**
	 * {@link PayrollVo#PayrollVo()}sB
	 */
	public StartCalcVo() {
		super();
	}
	
	/* (non-Javadoc)
	 * @see jp.mosp.payroll.base.PayrollVo#setSubTitle()
	 */
	@Override
	protected void setSubTitle() {
		super.setSubTitle();
		subTitle = getName("P_PAYROLL") + getName("C_START");
		addAryMenu("P1001", getName("P_PAYMENT") +
				getName("P_CALCULATE") + getName("C_MENU") + getName("C_TO"));
	}
	
	/**
	 * NGXgp[^擾Aݒ肷B
	 * @param request NGXg
	 */
	public void setParams(HttpServletRequest request) {
		pltYear  = getIntParam(request.getParameter(PRM_PLT_YEAR ));
		pltMonth = getIntParam(request.getParameter(PRM_PLT_MONTH));
	}
	
	/* (non-Javadoc)
	 * @see jp.mosp.payroll.base.PayrollVo#getDirectJs(Class)
	 */
	@Override
	public String getDirectJs(Class<?> cls) throws IllegalAccessException {
		StringBuffer sb = new StringBuffer();
		sb.append(super.getDirectJs(cls));
		sb.append("var MODE = ");
		sb.append(mode);
		sb.append(";");
		return sb.toString();
	}
	
	/**
	 * ^vZJn擾B
	 * @return ^vZJn
	 */
	public int getPltMonth() {
		return pltMonth;
	}

	/**
	 * ^vZJnݒ肷B
	 * @param pltMonth ݒ肷鋋^vZJn
	 */
	public void setPltMonth(int pltMonth) {
		this.pltMonth = pltMonth;
	}

	/**
	 * ^vZJnN擾B
	 * @return ^vZJnN
	 */
	public int getPltYear() {
		return pltYear;
	}

	/**
	 * ^vZJnNݒ肷B
	 * @param pltYear ݒ肷鋋^vZJnN
	 */
	public void setPltYear(int pltYear) {
		this.pltYear = pltYear;
	}

	/**
	 * v_EACe擾B
	 * @return v_EACe
	 */
	public String[][] getPitMonth() {
		return getAryField(pitMonth);
	}

	/**
	 * v_EACeݒ肷B
	 * @param pitMonth ݒ肷錎v_EACe
	 */
	public void setPitMonth(String[][] pitMonth) {
		this.pitMonth = getAryField(pitMonth);
	}

	/**
	 * Nv_EACe擾B
	 * @return Nv_EACe
	 */
	public String[][] getPitYear() {
		return getAryField(pitYear);
	}

	/**
	 * Nv_EACeݒ肷B
	 * @param pitYear ݒ肷Nv_EACe
	 */
	public void setPitYear(String[][] pitYear) {
		this.pitYear = getAryField(pitYear);
	}

	/**
	 * ʃ[hݒ肷B<br><br>
	 * 0:ʏA1FvZA2Fs
	 * @param mode ݒ肷ʃ[h
	 */
	public void setMode(int mode) {
		this.mode = mode;
	}
	
}

==> payroll_ver_3.3.0.zip: payroll3/src/jp/mosp/payroll/payment/vo/StartCalcVo.java <==
package jp.mosp.payroll.payment.vo;

import javax.servlet.http.HttpServletRequest;

import jp.mosp.payroll.base.PayrollVo;

/**
 * ^vZJnʂɊւB
 */
public class StartCalcVo extends PayrollVo {
	
	private static final long	serialVersionUID	= 6398055375236133331L;
	
	// tB[h
	private int					pltYear;
	private int					pltMonth;
	
	// v_E
	private String[][]			pitYear;
	private String[][]			pitMonth;
	
	// ʃ[h
	private int					mode;
	
	/**
	 * p[^(^vZJnN)B
	 */
	public static final String	PRM_PLT_YEAR		= "pltYear";
	
	/**
	 * p[^(^vZJn)B
	 */
	public static final String	PRM_PLT_MONTH		= "pltMonth";
	

	/**
	 * {@link PayrollVo#PayrollVo()}sB
	 */
	public StartCalcVo() {
		super();
	}
	
	/* (non-Javadoc)
	 * @see jp.mosp.payroll.base.PayrollVo#setSubTitle()
	 */
	@Override
	protected void setSubTitle() {
		super.setSubTitle();
		subTitle = getName("P_PAYROLL") + getName("C_START");
		addAryMenu("P1001", getName("P_PAYMENT") + getName("P_CALCULATE") + getName("C_MENU") + getName("C_TO"));
	}
	
	/**
	 * NGXgp[^擾Aݒ肷B
	 * @param request NGXg
	 */
	public void setParams(HttpServletRequest request) {
		pltYear = getIntParam(request.getParameter(PRM_PLT_YEAR));
		pltMonth = getIntParam(request.getParameter(PRM_PLT_MONTH));
	}
	
	/* (non-Javadoc)
	 * @see jp.mosp.payroll.base.PayrollVo#getDirectJs(Class)
	 */
	@Override
	public String getDirectJs(Class<?> cls) throws IllegalAccessException {
		StringBuffer sb = new StringBuffer();
		sb.append(super.getDirectJs(cls));
		sb.append("var MODE = ");
		sb.append(mode);
		sb.append(";");
		return sb.toString();
	}
	
	/**
	 * ^vZJn擾B
	 * @return ^vZJn
	 */
	public int getPltMonth() {
		return pltMonth;
	}
	
	/**
	 * ^vZJnݒ肷B
	 * @param pltMonth ݒ肷鋋^vZJn
	 */
	public void setPltMonth(int pltMonth) {
		this.pltMonth = pltMonth;
	}
	
	/**
	 * ^vZJnN擾B
	 * @return ^vZJnN
	 */
	public int getPltYear() {
		return pltYear;
	}
	
	/**
	 * ^vZJnNݒ肷B
	 * @param pltYear ݒ肷鋋^vZJnN
	 */
	public void setPltYear(int pltYear) {
		this.pltYear = pltYear;
	}
	
	/**
	 * v_EACe擾B
	 * @return v_EACe
	 */
	public String[][] getPitMonth() {
		return getAryField(pitMonth);
	}
	
	/**
	 * v_EACeݒ肷B
	 * @param pitMonth ݒ肷錎v_EACe
	 */
	public void setPitMonth(String[][] pitMonth) {
		this.pitMonth = getAryField(pitMonth);
	}
	
	/**
	 * Nv_EACe擾B
	 * @return Nv_EACe
	 */
	public String[][] getPitYear() {
		return getAryField(pitYear);
	}
	
	/**
	 * Nv_EACeݒ肷B
	 * @param pitYear ݒ肷Nv_EACe
	 */
	public void setPitYear(String[][] pitYear) {
		this.pitYear = getAryField(pitYear);
	}
	
	/**
	 * ʃ[hݒ肷B<br><br>
	 * 0:ʏA1FvZA2Fs
	 * @param mode ݒ肷ʃ[h
	 */
	public void setMode(int mode) {
		this.mode = mode;
	}
	
}
